@@ -122,7 +122,7 @@ FAILEDOPERATION_NOPERMISSION = 'FailedOperation.NoPermission'
 # 操作不允许。
 FAILEDOPERATION_NOTALLOW = 'FailedOperation.NotAllow'
 
-# 请求正在处理中，请稍候再试。
+# 请求正在处理中，请稍后再试。
 FAILEDOPERATION_PROCESSING = 'FailedOperation.Processing'
 
 # 查询资源标签失败。
@@ -185,6 +185,9 @@ INTERNALERROR_QUERYHDFSINFOFAILED = 'InternalError.QueryHDFSInfoFailed'
 # 查询预付费资源组详情失败。
 INTERNALERROR_QUERYRESOURCEGROUPFAILED = 'InternalError.QueryResourceGroupFailed'
 
+# 查询子网信息失败。
+INTERNALERROR_QUERYSUBNETINFOFAILED = 'InternalError.QuerySubnetInfoFailed'
+
 # 停止任务失败。
 INTERNALERROR_STOPJOBINSTANCEFAILED = 'InternalError.StopJobInstanceFailed'
 
@@ -269,7 +272,7 @@ OPERATIONDENIED = 'OperationDenied'
 # 余额不足，创建/更新失败。
 OPERATIONDENIED_BALANCEINSUFFICIENT = 'OperationDenied.BalanceInsufficient'
 
-# 后付费资源售罄。
+# 按量计费资源售罄。
 OPERATIONDENIED_BILLINGSTATUSRESOURCEINSUFFICIENT = 'OperationDenied.BillingStatusResourceInsufficient'
 
 # 觅影资源包余额不足，请先充值。
@@ -305,7 +308,7 @@ RESOURCESSOLDOUT = 'ResourcesSoldOut'
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
-# 资源不属于当前登陆用户主账号，无权限访问。
+# 资源不属于当前登录用户主账号，无权限访问。
 UNAUTHORIZEDOPERATION_NOPERMISSION = 'UnauthorizedOperation.NoPermission'
 
 # 未知参数错误。
